

PORT = 5000
DEBUG = False
HOST = "127.0.0.1"
DATA_FOLDER = ""

DEFAULT_COMMANDS = [
    {'name': 'test1', 'comment': 'tttttt', 'command': 'echo yusuf; echo duzgun'},
    {'name': 'test2', 'comment': 'wwwwww', 'command': 'erorrrrr'},
    {'name': 'test3', 'comment': 'long output', 'command': 'sleep 3; find ~; sleep3'}
]